@@ -35,7 +35,7 @@ async def progress_for_pyrogram(
     now = time()
     diff = now - sfw
     if pbar is not None:
-        pbar.update(current)
+        pbar.update((current / total) * 1024 * 1024)
         if current == total:
             pbar.set_description("uploaded")
     else:
@@ -72,6 +72,6 @@ async def progress_for_pyrogram(
             try:
                 await message.edit_text(text="{}\n {}".format(ud_type, tmp))
             except FloodWait as e:
-                await sleep(e.x)
+                await sleep(e.value)
             except:  # noqa: E722
                 pass
